@@ -1,13 +1,15 @@
-from pytest import approx
-
 from barril import units
 from barril.units import ObtainQuantity
-from barril.units.posc import CreateAreaQuantityFromLengthQuantity
-from barril.units.posc import CreateVolumeQuantityFromLengthQuantity
+from barril.units.posc import (
+    CreateAreaQuantityFromLengthQuantity,
+    CreateVolumeQuantityFromLengthQuantity,
+)
 from barril.units.unit_database import UnitDatabase
 
+from pytest import approx
 
-def testPoscFrequency(unit_database_posc) -> None:
+
+def testPoscFrequency(unit_database_posc):
     u1 = units.Scalar("frequency", 1, "Hz")
     assert u1.GetValue("GHz") == 1.0e-9
 
@@ -15,9 +17,9 @@ def testPoscFrequency(unit_database_posc) -> None:
     assert u1.GetValue("Hz") == 1e9
 
 
-def testPoscTime(unit_database_posc) -> None:
+def testPoscTime(unit_database_posc):
     """
-    These are the time-units available on posc.
+        These are the time-units available on posc.
     """
     units.Scalar("time", 100, "s")
     units.Scalar("time", 100, "min")
@@ -28,7 +30,7 @@ def testPoscTime(unit_database_posc) -> None:
     assert hs.GetValue("d") == d.GetValue("d")
 
 
-def testPoscTemperature(unit_database_posc) -> None:
+def testPoscTemperature(unit_database_posc):
     u1 = units.Scalar("thermodynamic temperature", 100, "degC")
     u2 = units.Scalar("thermodynamic temperature", 100, "degF")
     u3 = units.Scalar("thermodynamic temperature", 0, "degC")
@@ -53,7 +55,7 @@ def testPoscTemperature(unit_database_posc) -> None:
     assert u3.GetValue("degC") == u4.value
 
 
-def testPoscRankine(unit_database_posc) -> None:
+def testPoscRankine(unit_database_posc):
     rankine = [0.0, 100, 550, 1300]
     kelvin = [0.0, 55.55555, 305.55555, 722.22222]
     unit_database = unit_database_posc
@@ -62,7 +64,7 @@ def testPoscRankine(unit_database_posc) -> None:
     assert approx(obtained) == kelvin
 
 
-def testPoscLength(unit_database_posc) -> None:
+def testPoscLength(unit_database_posc):
     # 'length'
     u1 = units.Scalar("length", 10, "ft")
     u2 = units.Scalar("length", 100, "km")
@@ -82,7 +84,7 @@ def testPoscLength(unit_database_posc) -> None:
     assert u3.GetValue("yd") == u4.value
 
 
-def testPoscVolume(unit_database_posc) -> None:
+def testPoscVolume(unit_database_posc):
     million_cubic_meters = units.Scalar("volume", 1, "M(m3)")
     assert million_cubic_meters.value == 1.0
     assert million_cubic_meters.GetValue("m3") == 1.0e6
@@ -94,7 +96,7 @@ def testPoscVolume(unit_database_posc) -> None:
     assert cubic_meters.GetValue("1000m3") == 1.0e3
 
 
-def testPoscVolumeFlowRate(unit_database_posc) -> None:
+def testPoscVolumeFlowRate(unit_database_posc):
     million_cubic_meters = units.Scalar("volume flow rate", 1, "M(m3)/d")
     assert million_cubic_meters.value == 1.0
     assert million_cubic_meters.GetValue("m3/d") == 1.0e6
@@ -106,13 +108,13 @@ def testPoscVolumeFlowRate(unit_database_posc) -> None:
     assert cubic_meters.GetValue("1000m3/d") == 1.0e3
 
 
-def testPoscPermeabilityLength(unit_database_posc) -> None:
+def testPoscPermeabilityLength(unit_database_posc):
     unit_database = UnitDatabase.GetSingleton()
     assert "volume" == unit_database.GetQuantityType("mD.ft")
     assert "permeability length" == unit_database.GetDefaultCategory("mD.ft")
 
 
-def testPoscPermeability(unit_database_posc) -> None:
+def testPoscPermeability(unit_database_posc):
     # 'length'
     u1 = units.Scalar("permeability rock", 1, "D")
     u2 = units.Scalar("permeability rock", 1000, "mD")
@@ -125,14 +127,7 @@ def testPoscPermeability(unit_database_posc) -> None:
     assert approx(abs(u2.GetValue("D") - 1.0), 7) == 0
 
 
-def testPoscMolePerMass(unit_database_posc) -> None:
-    default = units.Scalar(1, "mol/kg")
-    assert default.GetQuantityType() == "mole per mass"
-
-    assert approx(abs(default.GetValue("mol/kg") - 1.0), 7) == 0
-
-
-def testPoscMolePerTime(unit_database_posc) -> None:
+def testPoscMolePerTime(unit_database_posc):
     default = units.Scalar(1, "mol/s")
     assert default.GetQuantityType() == "mole per time"
 
@@ -141,7 +136,7 @@ def testPoscMolePerTime(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("mol/d") - 1.0 * 86400.0), 7) == 0
 
 
-def testPoscRotationalFrequency(unit_database_posc) -> None:
+def testPoscRotationalFrequency(unit_database_posc):
     default = units.Scalar(1, "rad/s")
     assert default.GetQuantityType() == "frequency"
 
@@ -150,7 +145,7 @@ def testPoscRotationalFrequency(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("rev/s") - 0.15915494309644432), 7) == 0
 
 
-def testPoscAngularAcceleration(unit_database_posc) -> None:
+def testPoscAngularAcceleration(unit_database_posc):
     default = units.Scalar(1, "rad/s2")
     assert default.GetQuantityType() == "angular acceleration"
 
@@ -163,7 +158,7 @@ def testPoscAngularAcceleration(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("rpm/s") - 9.549296585786658), 7) == 0
 
 
-def testPoscDensity(unit_database_posc) -> None:
+def testPoscDensity(unit_database_posc):
     default = units.Scalar(1, "kg/m3")
     assert default.GetQuantityType() == "density"
 
@@ -172,7 +167,7 @@ def testPoscDensity(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("mg/cm3") - 1e6 / 1e6), 7) == 0
 
 
-def testPoscSpecificEnergy(unit_database_posc) -> None:
+def testPoscSpecificEnergy(unit_database_posc):
     default = units.Scalar(1, "J/kg")
     assert default.GetQuantityType() == "specific energy"
 
@@ -185,7 +180,7 @@ def testPoscSpecificEnergy(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("kW.h/tonUK") - 2.73390677574e-10), 20) == 0
 
 
-def testPoscMassPerEnergy(unit_database_posc) -> None:
+def testPoscMassPerEnergy(unit_database_posc):
     default = units.Scalar(1, "kg/J")
     assert default.GetQuantityType() == "mass per energy"
 
@@ -193,23 +188,7 @@ def testPoscMassPerEnergy(unit_database_posc) -> None:
     assert approx(abs(default.GetValue("lbm/Btu") - 1.0 / 0.0004299226139295), 7) == 0
 
 
-def testKinematicViscosity(unit_database_posc) -> None:
-    default = units.Scalar("kinematic viscosity", 1, "m2/s")
-    assert default.GetQuantityType() == "volume per time per length"
-    assert approx(abs(default.value - 1.0), 7) == 0
-    assert approx(abs(default.GetValue("cm2/s") - 10000.0), 7) == 0
-    assert approx(abs(default.GetValue("St") - 10000.0), 7) == 0
-    assert approx(abs(default.GetValue("cSt") - 1000000.0), 7) == 0
-    assert approx(abs(default.GetValue("ft2/h") - 318750.077500155), 7) == 0
-    assert approx(abs(default.GetValue("ft2/s") - 10.763910416709722), 7) == 0
-    assert approx(abs(default.GetValue("in2/s") - 1550.0031000062002), 7) == 0
-    assert approx(abs(default.GetValue("m2/h") - 3600.0), 7) == 0
-    assert approx(abs(default.GetValue("mm2/s") - 1000000.0), 7) == 0
-    assert approx(abs(default.GetValue("m2/d") - 86400.0), 7) == 0
-    assert approx(abs(default.GetValue("ft2/d") - 930001.8600037199), 7) == 0
-
-
-def testCreateVolumeQuantityFromLengthQuantity(unit_database_posc) -> None:
+def testCreateVolumeQuantityFromLengthQuantity(unit_database_posc):
     unit_database = unit_database_posc
     length_units = unit_database.GetValidUnits("length")
     convertable_length_units = ["m", "cm", "dm", "ft", "in", "km", "mi", "mm", "yd", "um"]
@@ -228,7 +207,7 @@ def testCreateVolumeQuantityFromLengthQuantity(unit_database_posc) -> None:
         assert volume_quantity.GetUnit() == "%s3" % length_unit
 
 
-def testCreateAreaQuantityFromLengthQuantity(unit_database_posc) -> None:
+def testCreateAreaQuantityFromLengthQuantity(unit_database_posc):
     unit_database = unit_database_posc
     length_units = unit_database.GetValidUnits("length")
     convertable_length_units = ["m", "cm", "ft", "in", "km", "mi", "miUS", "mm", "um", "yd"]
@@ -247,7 +226,7 @@ def testCreateAreaQuantityFromLengthQuantity(unit_database_posc) -> None:
         assert area_quantity.GetUnit() == "%s2" % length_unit
 
 
-def testDefaultCategories(unit_database_posc) -> None:
+def testDefaultCategories(unit_database_posc):
     """
     Check all units with categories defined
     """
@@ -294,6 +273,7 @@ def testDefaultCategories(unit_database_posc) -> None:
         "self inductance per length",
         "shear rate",
         "status",
+        "thermodynamic temperature",
         "volume per area",
         "volume per length",
         "volume per time per area",
@@ -302,7 +282,7 @@ def testDefaultCategories(unit_database_posc) -> None:
     ]
 
 
-def testPoscValidUnitsNotRepeated(unit_database_posc) -> None:
+def testPoscValidUnitsNotRepeated(unit_database_posc):
     unit_database = unit_database_posc
     for category in unit_database.IterCategories():
         valid_units = unit_database.GetValidUnits(category)
@@ -311,7 +291,7 @@ def testPoscValidUnitsNotRepeated(unit_database_posc) -> None:
         ), f'There is a duplicate unit defined in "{category}": {valid_units}'
 
 
-def testPoscKVmm(unit_database_posc) -> None:
+def testPoscKVmm(unit_database_posc):
     """
     V/m to KV/mm (multiply by 1e6)
     """
@@ -319,7 +299,7 @@ def testPoscKVmm(unit_database_posc) -> None:
     assert q.ConvertScalarValue(1, "KV/mm") == 1e6
 
 
-def testPoscBytes(unit_database_posc) -> None:
+def testPoscBytes(unit_database_posc):
     """
     Bytes, kBytes, MBytes, ....
     """
@@ -330,12 +310,12 @@ def testPoscBytes(unit_database_posc) -> None:
     assert q.ConvertScalarValue(1024 * 1024 * 1024 * 1024, "TByte") == 1
 
 
-def testOhmUnits(unit_database_posc) -> None:
+def testOhmUnits(unit_database_posc):
     q = ObtainQuantity("ohm/m")
     assert q.ConvertScalarValue(1, "ohm/km") == 1000
 
 
-def testPower(unit_database_posc) -> None:
+def testPower(unit_database_posc):
     unit_database = unit_database_posc
     assert "volt ampere" == ObtainQuantity("VA").GetQuantityType()
     assert "volt ampere reactive" == ObtainQuantity("VAr").GetQuantityType()
@@ -353,7 +333,7 @@ def testPower(unit_database_posc) -> None:
     )
 
 
-def testFluidGasConcentration(unit_database_posc) -> None:
+def testFluidGasConcentration(unit_database_posc):
     """
     Total Gas Unit requested for PWDA as concentration
     """
@@ -366,7 +346,7 @@ def testFluidGasConcentration(unit_database_posc) -> None:
     assert approx(abs(q.ConvertScalarValue(1, "Euc") - 0.00033333), 7) == 0
 
 
-def testSpringDashpotUnits(unit_database_posc) -> None:
+def testSpringDashpotUnits(unit_database_posc):
     """
     Units used to define Spring-Dashpot movements
     """
@@ -384,7 +364,7 @@ def testSpringDashpotUnits(unit_database_posc) -> None:
     assert approx(abs(q.ConvertScalarValue(1, "lbf.ft.s/dega") - 0.017453292519943), 7) == 0
 
 
-def testConcentrationRatio(unit_database_posc) -> None:
+def testConcentrationRatio(unit_database_posc):
     """
     Units used to express a ratio of concentrations
     """
@@ -392,7 +372,7 @@ def testConcentrationRatio(unit_database_posc) -> None:
     assert concentration_ratio_units == ["mg/l/mg/l", "kg/m3/kg/m3"]
 
 
-def testJouleThomsonCoefficientUnits() -> None:
+def testJouleThomsonCoefficientUnits():
     """
     Results gathered from NIST.
     """
@@ -419,7 +399,7 @@ def testJouleThomsonCoefficientUnits() -> None:
     assert joule_thomson_si_units_mega.GetValue("degF/bar") == approx(9 / 5 * 1e1)
 
 
-def testDensityDerivativePerTemperatureUnitConversion() -> None:
+def testDensityDerivativePerTemperatureUnitConversion():
     density_derivative_per_temperature = units.Scalar(
         "density derivative in respect to temperature", 1, "kg/m3.degC"
     )
@@ -430,91 +410,3 @@ def testDensityDerivativePerTemperatureUnitConversion() -> None:
         "density derivative in respect to temperature", 1, "kg/m3.K"
     )
     assert density_derivative_per_temperature.GetValue("kg/m3.degC") == 1.0
-
-
-def testStandardVolumePerStandardVolumeSmoke() -> None:
-    standard_per_standard = units.Scalar(
-        "standard volume per standard volume", 1, "scm(15C)/scm(15C)"
-    )
-    assert standard_per_standard.GetValue("scm(15C)/scm(15C)") == approx(1.0)
-    assert standard_per_standard.GetValue("scf(60F)/stb") == approx(5.625408383313)
-    assert standard_per_standard.GetValue("scf(60F)/scf") == approx(1.001928010069)
-    assert standard_per_standard.GetValue("stb(60F)/stb") == approx(1.0)
-    assert standard_per_standard.GetValue("sm3/sm3") == approx(1.0)
-    assert standard_per_standard.GetValue("scm3/scm3") == approx(1.0)
-    assert standard_per_standard.GetValue("stb/stb") == approx(1.0)
-    assert standard_per_standard.GetValue("Mscf/stb") == approx(0.0056254083833)
-    assert standard_per_standard.GetValue("MMscf/stb") == approx(0.0000056254083833)
-    assert standard_per_standard.GetValue("scf/stb") == approx(5.62540838331)
-    assert standard_per_standard.GetValue("stb/scf") == approx(0.17776487178535644)
-    assert standard_per_standard.GetValue("stb/MMscf") == approx(177764.87178535643)
-
-
-def testHeatTransferCoefficient() -> None:
-    default = units.Scalar("heat transfer coefficient", 1, "W/m2.K")
-    assert default.value == 1.0
-    assert default.GetValue("Btu/hr.ft2.degF") == approx(0.17611019426187197)
-    assert default.GetValue("Btu/hr.ft2.degR") == approx(0.17611019426187197)
-    assert default.GetValue("Btu/hr.m2.degC") == approx(3.412141285851795)
-    assert default.GetValue("Btu/s.ft2.degF") == approx(4.891949074810131e-05)
-    assert default.GetValue("cal/h.cm2.degC") == approx(0.08604208146120104)
-    assert default.GetValue("cal/s.cm2.degC") == approx(2.390057361376673e-05)
-    assert default.GetValue("J/s.m2.degC") == approx(1.0)
-    assert default.GetValue("kcal/h.m2.degC") == approx(0.8604208146120104)
-    assert default.GetValue("cal/h.m2.degC") == approx(860.4208146120104)
-    assert default.GetValue("kJ/h.m2.K") == approx(3.6)
-    assert default.GetValue("kW/m2.K") == approx(0.001)
-
-
-def testProductivityIndex() -> None:
-    default = units.Scalar("productivity index", 1, "m3/Pa.s")
-    assert default.value == 1.0
-    assert default.GetValue("Mcf/psi.d") == approx(21037191.806292012)
-    assert default.GetValue("ft3/psi.d") == approx(21037191806.292012)
-    assert default.GetValue("bbl/d.psi") == approx(3746884212.8623204)
-    assert default.GetValue("bbl/kPa.d") == approx(543439633.228566)
-    assert default.GetValue("bbl/psi.d") == approx(3746884215.280088)
-    assert default.GetValue("L/bar.min") == approx(6000000000.0)
-    assert default.GetValue("m3/bar.d") == approx(8640000000.0)
-    assert default.GetValue("m3/bar.h") == approx(360000000.0)
-    assert default.GetValue("m3/bar.min") == approx(6000000.0)
-    assert default.GetValue("m3/d.kPa") == approx(86400000.0)
-    assert default.GetValue("m3/kPa.d") == approx(86400000.0)
-    assert default.GetValue("m3/kPa.h") == approx(3600000.0)
-    assert default.GetValue("m3/psi.d") == approx(595707004.8)
-
-
-def testThermalConductivity() -> None:
-    default = units.Scalar("thermal conductivity", 1, "W/m.K")
-    assert default.GetValue("Btu/hr.ft.degF") == approx(0.5777892051642799)
-    assert default.GetValue("cal/h.cm.degC") == approx(8.604208146120104)
-    assert default.GetValue("cal/s.cm.degC") == approx(0.002390057361376673)
-    assert default.GetValue("cal/m.h.degC") == approx(860.4208146120104)
-    assert default.GetValue("kcal/h.m.degC") == approx(0.8604208146120104)
-    assert default.GetValue("Btu/d.ft.degF") == approx(13.867702121758425)
-    assert default.GetValue("kJ/d.m.K") == approx(86.4304235090752)
-    assert default.GetValue("W/m.degC") == approx(1.0)
-
-
-def testStandardVolumePerTime() -> None:
-    default = units.Scalar("standard volume per time", 1, "scm(15C)/s")
-    assert default.GetValue("ksm3/d") == approx(86.4)
-    assert default.GetValue("MMscf(60F)/d") == approx(3.0570698685888087)
-    assert default.GetValue("MMscm(15C)/d") == approx(0.0864)
-    assert default.GetValue("MMstb(60F)/d") == approx(0.5434396332285661)
-    assert default.GetValue("Mscf(60F)/d") == approx(3057.0698685888087)
-    assert default.GetValue("Mscm(15C)/d") == approx(86.4)
-    assert default.GetValue("Mstb(60F)/d") == approx(543.4396332285661)
-    assert default.GetValue("scf(60F)/d") == approx(3057069.868588809)
-    assert default.GetValue("scm(15C)/d") == approx(86400.0)
-    assert default.GetValue("stb(60F)/d") == approx(543439.6332285661)
-    assert default.GetValue("MMscf/d") == approx(3.0570698685888087)
-    assert default.GetValue("MMsm3/d") == approx(0.0864)
-    assert default.GetValue("MMstb/d") == approx(0.5434396332285661)
-    assert default.GetValue("Mscf/d") == approx(3057.069868588809)
-    assert default.GetValue("Msm3/d") == approx(0086.4)
-    assert default.GetValue("Mstb/d") == approx(543.4396332285661)
-    assert default.GetValue("scf/d") == approx(3057069.868588809)
-    assert default.GetValue("sm3/d") == approx(86400.0)
-    assert default.GetValue("stb/d") == approx(543439.6332285661)
-    assert default.GetValue("sm3/s") == approx(1.0)
