@@ -1,45 +1,46 @@
 """
     The 'unit' must be ascii only.
 """
-from collections import OrderedDict
 
 import pytest
+from collections import OrderedDict
+from barril import units
+from barril.units import (
+    ChangeScalars,
+    InvalidOperationError,
+    InvalidUnitError,
+    ObtainQuantity,
+    Quantity,
+    Scalar,
+)
 from pytest import approx
 
-from barril import units
-from barril.units import ChangeScalars
-from barril.units import InvalidOperationError
-from barril.units import InvalidUnitError
-from barril.units import ObtainQuantity
-from barril.units import Quantity
-from barril.units import Scalar
 
-
-def testScalarInterface(unit_database_well_length) -> None:
+def testScalarInterface(unit_database_well_length):
     s = Scalar("well-length")
     assert 0 == s.value
     assert "m" == s.unit
 
 
-def testQuantity(unit_database_well_length) -> None:
+def testQuantity(unit_database_well_length):
     Quantity("well-length", "m")
     with pytest.raises(units.InvalidQuantityTypeError):
         Quantity("foo", "m")
 
 
-def testQuantityEq(unit_database_well_length) -> None:
+def testQuantityEq(unit_database_well_length):
     q0 = ObtainQuantity("m", "well-length")
     q1 = ObtainQuantity("m", "well-length")
     assert q0 == q1
 
 
-def testReadOnlyQuantityCopy(unit_database_well_length) -> None:
+def testReadOnlyQuantityCopy(unit_database_well_length):
     q0 = ObtainQuantity("m", "well-length")
     q1 = q0.Copy()
     assert q0 == q1
 
 
-def testScalar(unit_database_well_length) -> None:
+def testScalar(unit_database_well_length):
     q = ObtainQuantity("m", "well-length")
     s = Scalar.CreateWithQuantity(q, 10)
 
@@ -59,13 +60,13 @@ def GetQuantity(unit="cm"):
     return units.ObtainQuantity(unit, "well-length")
 
 
-def testBadUnit(unit_database_well_length) -> None:
+def testBadUnit(unit_database_well_length):
     x = units.Scalar.CreateWithQuantity(GetQuantity(), 500)
     with pytest.raises(units.InvalidUnitError):
         x.CreateCopy(unit="invalidUnit")
 
 
-def testOperations(unit_database_well_length) -> None:
+def testOperations(unit_database_well_length):
     x = units.Scalar.CreateWithQuantity(GetQuantity(), 500)
     assert x.value == 500
     assert x.unit == "cm"
@@ -81,7 +82,7 @@ def unit(value, unit="m"):
     return units.Scalar.CreateWithQuantity(GetQuantity(unit), value)
 
 
-def testEq(unit_database_well_length) -> None:
+def testEq(unit_database_well_length):
     u1 = units.Scalar.CreateWithQuantity(GetQuantity(), 1.0)
     u2 = units.Scalar.CreateWithQuantity(GetQuantity(), 1.0)
     assert u1 == u2
@@ -89,7 +90,7 @@ def testEq(unit_database_well_length) -> None:
     assert "cm" == u2.unit
 
 
-def testAddUnit(unit_database_empty) -> None:
+def testAddUnit(unit_database_empty):
     unit_database = unit_database_empty
     unit_database.AddUnitBase("length", "metre", "m")
     RATIO = 0.0254
@@ -114,7 +115,7 @@ def testAddUnit(unit_database_empty) -> None:
     assert a == f
 
 
-def testValidUnits(unit_database_empty) -> None:
+def testValidUnits(unit_database_empty):
     # let'scalar clear up the unit manager
     unit_database = unit_database_empty
 
@@ -144,7 +145,7 @@ def testValidUnits(unit_database_empty) -> None:
     assert scalar.GetValidUnits() == ["m", "cm", "mm", "mi"]
 
 
-def testScalarCopyAndRepresentation(unit_database_empty) -> None:
+def testScalarCopyAndRepresentation(unit_database_empty):
     unit_database = unit_database_empty
 
     unit_database.AddUnitBase("length", "meters", "m")
@@ -164,7 +165,7 @@ def testScalarCopyAndRepresentation(unit_database_empty) -> None:
     assert "1000 [cm]" == str(s)
 
 
-def testSort(unit_database_empty) -> None:
+def testSort(unit_database_empty):
     db = unit_database_empty
 
     db.AddUnitBase("length", "meters", "m")
@@ -181,7 +182,7 @@ def testSort(unit_database_empty) -> None:
     assert x == [s1, s2, s3, s4]
 
 
-def testCategoryParameters(unit_database_empty) -> None:
+def testCategoryParameters(unit_database_empty):
     db = unit_database_empty
 
     db.AddUnitBase("length", "meters", "m")
@@ -229,7 +230,7 @@ def testCategoryParameters(unit_database_empty) -> None:
     assert not another.IsValid()
 
 
-def testInvalidUnit(unit_database_empty) -> None:
+def testInvalidUnit(unit_database_empty):
     unit_database = unit_database_empty
 
     unit_database.AddUnitBase("length", "meters", "m")
@@ -240,7 +241,7 @@ def testInvalidUnit(unit_database_empty) -> None:
         Scalar("well-diameter", 10, "days")
 
 
-def testDerivedUnits(unit_database_empty) -> None:
+def testDerivedUnits(unit_database_empty):
     unit_database = unit_database_empty
 
     unit_database.AddUnitBase("length", "meters", "m")
@@ -264,7 +265,7 @@ def testDerivedUnits(unit_database_empty) -> None:
         s1.__sub__(s3)
 
 
-def testCreationWithDerivedQuantity(unit_database_len_time) -> None:
+def testCreationWithDerivedQuantity(unit_database_len_time):
     unit_database = unit_database_len_time
 
     m = Quantity.CreateDerived(OrderedDict([("Table size", ["m", 1])]))
@@ -279,7 +280,7 @@ def testCreationWithDerivedQuantity(unit_database_len_time) -> None:
     assert calculated1 == s1 * s2
 
 
-def testNumberInteractions(unit_database_len_time) -> None:
+def testNumberInteractions(unit_database_len_time):
     scalar = Scalar("Table size", 1, "m")
     scalar2 = Scalar.CreateWithQuantity(Quantity.CreateDerived(OrderedDict()), 0)
 
@@ -298,7 +299,7 @@ def testNumberInteractions(unit_database_len_time) -> None:
     assert 1 / 10.0 == (scalar / 10.0).value
 
 
-def testDivision(unit_database_len_time) -> None:
+def testDivision(unit_database_len_time):
     unit_database = unit_database_len_time
 
     m = Quantity.CreateDerived(OrderedDict([("Table size", ["m", 1])]))
@@ -310,7 +311,7 @@ def testDivision(unit_database_len_time) -> None:
     assert calculated1 == s1 / s2
 
 
-def testFloorDivision() -> None:
+def testFloorDivision():
     a = Scalar(3.5, "m")
     b = Scalar(100.0, "cm")
     assert (a // b).GetValueAndUnit() == (3.0, "")
@@ -318,7 +319,7 @@ def testFloorDivision() -> None:
     assert (a // 1.0).GetValueAndUnit() == (3.0, "m")
 
 
-def testNumberOverScalar() -> None:
+def testNumberOverScalar():
     a = Scalar(2.0, "m")
     b = Scalar(3.0, "m")
     assert (1.0 / a).GetValueAndUnit() == (0.5, "1/m")
@@ -326,16 +327,16 @@ def testNumberOverScalar() -> None:
     assert b / a == b * 1 / a == b * (1.0 / a)
 
 
-def testPow(unit_database_len_time) -> None:
+def testPow(unit_database_len_time):
     s = Scalar(2, "s", "Time")
-    spow = s**3
+    spow = s ** 3
     assert spow.unit == "s3"
     assert spow.value == 8
 
 
-def testFormatedUnitsOnScalar(unit_database_empty) -> None:
+def testFormatedUnitsOnScalar(unit_database_empty):
     """
-    Allow present units on get formatted Scalar
+        Allow present units on get formatted Scalar
     """
     unit_database = unit_database_empty
     unit_database.AddUnitBase("length", "meters", "m")
@@ -372,13 +373,13 @@ def testFormatedUnitsOnScalar(unit_database_empty) -> None:
     # Make sure we didn't affect the Scalar class, only the local MyScalar
     MyScalar.SetFormattedValueFormat("<<< %f")
     MyScalar.SetFormattedSuffixFormat(" [%s] >>>")
-    scalar2 = Scalar("length", 1.18, "m")
-    assert scalar2.GetFormatted() == "1.18 [m]"
+    scalar = Scalar("length", 1.18, "m")
+    assert scalar.GetFormatted() == "1.18 [m]"
 
 
-def testEmptyScalar() -> None:
+def testEmptyScalar():
     """
-    ScalarMultiData exception when some of its scalars don't have a quantity_type
+        ScalarMultiData exception when some of its scalars don't have a quantity_type
     """
     # An empty scalar doesn't have a category defined
     scalar_1 = Scalar.CreateEmptyScalar(20.0)
@@ -388,9 +389,9 @@ def testEmptyScalar() -> None:
     assert scalar_1.GetUnit() == ""
 
 
-def testCopyProperties(unit_database_well_length) -> None:
+def testCopyProperties(unit_database_well_length):
     """
-    Test if the mehod SetValue is not called when copying the Scalar's properties.
+        Test if the mehod SetValue is not called when copying the Scalar's properties.
     """
     category = "well-length"
     unit = "m"
@@ -404,7 +405,7 @@ def testCopyProperties(unit_database_well_length) -> None:
     assert scalar_dest.GetValue() == value
 
 
-def testCopyPropertiesAndValidation(unit_database_well_length) -> None:
+def testCopyPropertiesAndValidation(unit_database_well_length):
     category = "well-length-with-min-and-max"  # the minimum value is zero
     unit = "m"
     value = -1
@@ -419,10 +420,10 @@ def testCopyPropertiesAndValidation(unit_database_well_length) -> None:
     assert not another.IsValid()
 
 
-def testDefaultValue(unit_database_len_pressure) -> None:
+def testDefaultValue(unit_database_len_pressure):
     """
-    Scalar constructor considers the minimum and maximum values
-    when default_value is not defined
+        Scalar constructor considers the minimum and maximum values
+        when default_value is not defined
     """
     db = unit_database_len_pressure
 
@@ -508,7 +509,7 @@ def testDefaultValue(unit_database_len_pressure) -> None:
         )
 
 
-def testScalarInvalidValue(unit_database_len_time) -> None:
+def testScalarInvalidValue(unit_database_len_time):
     db = unit_database_len_time
 
     db.AddCategory("another-length", "length", min_value=0, max_value=15)
@@ -542,7 +543,7 @@ def testScalarInvalidValue(unit_database_len_time) -> None:
     assert copied.GetFormatted() == "300000 [cm]"
 
 
-def testScalarValidUnits(unit_database_empty) -> None:
+def testScalarValidUnits(unit_database_empty):
     db = unit_database_empty
     db.AddUnit("length", "milimeters", "mm", "%f * 1000.0", "%f / 1000.0")
     db.AddUnitBase("length", "meters", "m")
@@ -558,7 +559,7 @@ def testScalarValidUnits(unit_database_empty) -> None:
     assert s2 is not None
 
 
-def testScalarRepresentation(unit_database_posc) -> None:
+def testScalarRepresentation(unit_database_posc):
     s1 = Scalar(0.5, "kg/kg", "dimensionless")
     s2 = Scalar(0.125, "g/g", "mass concentration")
 
@@ -569,7 +570,7 @@ def testScalarRepresentation(unit_database_posc) -> None:
     assert repr(s2) == "Scalar(0.125, 'g/g', 'mass concentration')"
 
 
-def testScalarCreationModes() -> None:
+def testScalarCreationModes():
     base = Scalar(10, "m")
 
     assert Scalar("length", 10, "m") == base
@@ -579,7 +580,7 @@ def testScalarCreationModes() -> None:
         Scalar("length", 1.0)  # missing unit
 
 
-def testScalarPickle(unit_database_posc) -> None:
+def testScalarPickle(unit_database_posc):
 
     import pickle
 
@@ -592,7 +593,7 @@ def testScalarPickle(unit_database_posc) -> None:
     assert complex_scalar == complex_scalar2
 
 
-def testScalarHashEq() -> None:
+def testScalarHashEq():
     scalar1 = Scalar("length", 10, "m")
     scalar2 = Scalar("length", 10, "m")
     scalar3 = Scalar("length", 10, "cm")
@@ -607,7 +608,7 @@ def testScalarHashEq() -> None:
     assert hash(scalar4) != hash(scalar3)
 
 
-def testChangeScalars() -> None:
+def testChangeScalars():
     class Fluid:
         density = Scalar(0, "lbm/galUS")
         concentration = Scalar(0, "%")
